<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Coast
 * @since Coast 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function coast_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'coast' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function coast_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'coast' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function coast_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'coast' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

function coast_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'coast' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}


if ( ! function_exists( 'coast_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function coast_selected_sidebar() {
        $coast_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'coast' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'coast' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'coast' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'coast' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'coast' ),
        );

        $output = apply_filters( 'coast_selected_sidebar', $coast_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'coast_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function coast_site_layout() {
        $coast_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'coast_site_layout', $coast_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'coast_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function coast_global_sidebar_position() {
        $coast_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'coast_global_sidebar_position', $coast_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'coast_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function coast_sidebar_position() {
        $coast_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'coast_sidebar_position', $coast_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'coast_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function coast_pagination_options() {
        $coast_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'coast' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'coast' ),
        );

        $output = apply_filters( 'coast_pagination_options', $coast_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'coast_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function coast_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'coast' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'coast' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'coast' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'coast' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'coast' ),
            'spinner-dots'          => esc_html__( 'Dots', 'coast' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'coast' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'coast' ),
        );
        return apply_filters( 'coast_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'coast_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function coast_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'coast' ),
            'off'       => esc_html__( 'Disable', 'coast' )
        );
        return apply_filters( 'coast_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'coast_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function coast_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'coast' ),
            'off'       => esc_html__( 'No', 'coast' )
        );
        return apply_filters( 'coast_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'coast_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function coast_sortable_sections() {
        $sections = array(
            'hero_banner'                       => esc_html__( 'Hero Banner', 'coast' ),
            'featured'                          => esc_html__( 'Featured', 'coast' ),
            'blog'                              => esc_html__( 'Blog', 'coast' ),
            'testimonial'                       => esc_html__( 'Testimonial', 'coast' ),
            'destination'                       => esc_html__( 'Destination', 'coast' ),
            'about'                             => esc_html__( 'About', 'coast' ),
            'gallery'                           => esc_html__( 'Gallery', 'coast' ),
            'counter'                           => esc_html__( 'Counter', 'coast' ),
            'subscribe'                         => esc_html__( 'Subscribe Us', 'coast' ),
        );
        return apply_filters( 'coast_sortable_sections', $sections );
    }
endif;



if ( ! function_exists( 'coast_blog_content_type' ) ) :
    /**
     * blog options
     * @return array site blog options
     */
    function coast_blog_content_type() {
        $coast_blog_content_type = array(
            'category'  => esc_html__( 'Category', 'coast' ),
        );

        $output = apply_filters( 'coast_blog_content_type', $coast_blog_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'coast_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function coast_featured_content_type() {
        if ( class_exists( 'WP_Travel' ) ) {
            $coast_featured_content_type = array(
                'trip'          => esc_html__( 'Trip', 'coast' ),
            );
        }
        $output = apply_filters( 'coast_featured_content_type', $coast_featured_content_type );
        return $output;
    }
endif;
// coast_destination_content_type
if ( !function_exists('coast_destination_content_type')):
        /**
     * Destination Options
     * @return array site destination
     */
    function coast_destination_content_type() {
        if ( class_exists( 'WP_Travel' ) ) {
            $coast_destination_content_type =  array(
                'destination'   => esc_html__( 'Destination', 'coast' ),
                );
        }

        $output = apply_filters( 'coast_destination_content_type', $coast_destination_content_type );


        return $output;
    }
endif;

